# Pile Cap

_A stable foundation for reproducible builds_


## Value proposition
This project aims to be both a map and a vehicle to reproducible builds.
It adopts the progressive disclosure pattern to accommodate both novices and veterans.
For the novice _porcelain_ commands can be used to set up a simple workflow.
For the veteran _plumbing_ commands can be combined with other tools such as `pip` and `pip-tools` to create more complicated workflows.
